<?php
/**
 * Plugin Name: Five Star Restaurant Reservations - Payment Gateway (NewGateway)
 * Description: NewGateway payment gateway for Restaurant reservations.
 * Version: 0.1
 * Author: FiveStarPlugins
 * Author URI: https://profiles.wordpress.org/fivestarplugins/
 * Text Domain: restaurant-reservations-new-gateway
 */
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

define( 'RTB_NEW_GATEWAY_PLUGIN_DIR', untrailingslashit( plugin_dir_path( __FILE__ ) ) );

add_action( 'rtb_payment_manager_load_gateways' , function() {
    global $rtb_controller;
    
    if( !isset( $rtb_controller ) || !( $rtb_controller instanceof rtbInit ) ) {
        new_gateway_notify_admin();
        return;
    }

    // Load NewGateway payment gateway class
    require_once( RTB_NEW_GATEWAY_PLUGIN_DIR . '/NewGateway.class.php' );

    /**
     * Gateway has to register itself
     */
    add_filter( 'rtb-payment-gateway-register', array( 'rtbNewGateway', 'register_gateway' ) );
}, 5 );

/**
 * A message to admin about the requirement of parent plugin
 * */
function new_gateway_notify_admin() {
    add_action(
        'after_plugin_row_restaurant-reservations-new-gateway/restaurant-reservations-new-gateway.php',
        function($plugin_file, $plugin_data, $status) {
            global $page, $s;

            $plugin_slug    = isset( $plugin_data['slug'] ) ? $plugin_data['slug'] : sanitize_title( $plugin_data['Name'] );
            $plugin_id_attr = $plugin_slug;

            $is_active = is_plugin_active( $plugin_file );

            $parent_plugin = 'restaurant-reservations/restaurant-reservations.php';
            $is_active_parent = is_plugin_active( $parent_plugin );

            if( $is_active && !$is_active_parent ) {

                $activate = sprintf(
                    '<a href="%s" id="activate-%s" class="edit" aria-label="%s">%s</a>',
                    wp_nonce_url( 'plugins.php?action=activate&amp;plugin=' . urlencode( $parent_plugin ) . '&amp;plugin_status=' . $status . '&amp;paged=' . $page . '&amp;s=' . $s, 'activate-plugin_' . $parent_plugin ),
                    esc_attr( $plugin_id_attr ),
                    /* translators: %s: Plugin name. */
                    esc_attr( sprintf( _x( 'Activate %s', 'plugin' ), $plugin_data['Name'] ) ),
                    __( 'activate' )
                );;

                echo <<<HTML
                    <tr class="plugin-update-tr active" id="{$plugin_id_attr}">
                        <td colspan="4" class="plugin-update colspanchange">
                            <div class="notice inline notice-warning notice-alt">
                                <p>This is an extension plugin of <b>Five Star Restaurant Reservations</b>. You need to {$activate} <b>Five Star Restaurant Reservations</b> to utilise this.</p>
                            </div>
                            <script type="text/javascript">
                                jQuery(document).ready(function () {
                                    let $ = jQuery;
                                    $('#{$plugin_id_attr}').prev().addClass('update');
                                });
                            </script>
                        </td>
                    </tr>
                HTML;
            }
        },
        10,
        3
    );
}